@@ -9,6 +9,7 @@ from fast_tracker import Layer, ComponentType
 from fast_tracker.trace import tags
 from fast_tracker.trace.context import get_context
 from fast_tracker.trace.tags import Tag
+from fast_tracker.utils import functions
 
 
 def install():
@@ -18,7 +19,7 @@ def install():
 
     def _fast_send_command(this: Connection, *args, **kwargs):
         peer = "%s:%s" % (this.host, this.port)
-        op = args[0]
+        op = " ".join([str(i) for i in args]) + " " + str(kwargs)
         context = get_context()
         with context.new_exit_span(op="Redis/" + op or "/", peer=peer) as span:
             span.layer = Layer.Cache
@@ -27,6 +28,7 @@ def install():
             span.tag(Tag(key=tags.CacheType, val=ComponentType.Redis))
             span.tag(Tag(key=tags.CacheInstance, val=this.db))
             span.tag(Tag(key=tags.CacheCommand, val=op))
+            functions.log("redis span is: %r", span)
 
             return res
 
