@@ -15,8 +15,8 @@ HttpUrl = "url"
 HttpPath = "path"
 HttpMethod = "http_method"
 HttpStatus = "status_code"
-HttpParams = "http_query"
-HttpBody = "http_body"
+HttpParams = "http_params"
+HttpHeaders = "http_headers"
 
 # db
 DbType = "db_type"
